@@ -1,3 +1,6 @@
+#!/usr/bin/env python
+# encoding: utf-8
+
 import os
 import logging
 
@@ -6,7 +9,7 @@ import unittest
 from clickgen.linker import __main__ as linker
 
 
-class TestLinke(unittest.TestCase):
+class TestLinker(unittest.TestCase):
 
     # setup
     def setUp(self):
